#!/bin/bash
# Original code was:
# xjjk's Mozilla Projects Build Script v1.1
# Modified by Gilbert Ashley  -Nov 2005, Feb 2006

# Setup:
# Change the variables below to suit where your sources are and what options
# you want with your build.

# Description of script variables:
# BUILDDIR : Where things will be built. Preferably a fast disk with ample
#  space (200+ MB)
# MOZSRCDIR : The root of the mozilla sources

# General use:
# 1. Build desired project by using "build-mozilla.sh projectname"
# 2. Go into $BUILDDIR/projectname-build, and install, or test by
#     running one of the binaries in dist/bin

CWD=`pwd`
BUILDDIR=$CWD
MOZSRCDIR=$CWD/mozilla
MAKECMD="make -j3"

export MOZ_MAKE_FLAGS="-j3"
#export MOZ_INTERNAL_LIBART_LGPL=1
#export MOZILLA_OFFICIAL=0
#export BUILD_OFFICIAL=0
export CC="ccache gcc"
export CXX="ccache g++"
export CFLAGS="-O2 -march=i586 -mcpu=i686"
export CXXFLAGS=$CFLAGS

cd $BUILDDIR

base-configure-cmd(){
	echo -n \
	configure \
		--prefix=/usr \
		--disable-short-wchar \
		--disable-debug \
		--disable-tests \
		--enable-strip \
		--enable-strip-libs \
		--enable-nspr-autoconf \
		--without-system-nspr \
		--with-default-mozilla-five-home=/usr/lib/mozilla-1.7.12 \
		--disable-xprint \
		--disable-installer \
		--disable-freetype2 \
		--enable-xft \
		--with-system-zlib
}
	
case "$1" in
	firefox-std)
		cd $BUILDDIR
		mkdir firefox-std-build firefox-std-pkg
		export MOZ_PHOENIX=1
		cd firefox-std-build
		$MOZSRCDIR/`base-configure-cmd` \
			--enable-optimize="$CFLAGS" \
			--with-user-appdir=.firefox \
			--enable-extensions=default,irc \
			--disable-ldap \
			--disable-composer \
			--disable-mailnews \
			--enable-crypto
			
		BUILD_OFFICIAL=0 MOZILLA_OFFICIAL=0 MOZ_PHOENIX=1 $MAKECMD -s export
		BUILD_OFFICIAL=0 MOZILLA_OFFICIAL=0 MOZ_PHOENIX=1 $MAKECMD -s libs
		BUILD_OFFICIAL=0 MOZILLA_OFFICIAL=0 MOZ_PHOENIX=1 DESTDIR=$BUILDDIR/firefox-std-pkg make install
		;;
	mozilla-std)
		cd $BUILDDIR && mkdir mozilla-std-build mozilla-std-pkg
		cd $BUILDDIR/mozilla-std-build
		export BUILD_MODULES=all
		BUILD_OFFICIAL=1 MOZILLA_OFFICIAL=1 \
		$MOZSRCDIR/`base-configure-cmd` \
			--enable-crypto \
			--enable-calendar \
			--enable-optimize="$CFLAGS" \
			--enable-extensions=default,irc \
			--with-user-appdir=.mozilla
			
		BUILD_OFFICIAL=1 MOZILLA_OFFICIAL=1 make export
		BUILD_OFFICIAL=1 MOZILLA_OFFICIAL=1 make libs
		BUILD_OFFICIAL=1 MOZILLA_OFFICIAL=1 DESTDIR=$BUILDDIR/mozilla-std-pkg make install
		;;
	thunderbird-std)
		cd $BUILDDIR && mkdir thunderbird-std-build thunderbird-std-pkg
		export MOZ_THUNDERBIRD=1
		cd $BUILDDIR/thunderbird-std-build
		$MOZSRCDIR/`base-configure-cmd` \
			--enable-optimize="$CFLAGS" \
			--with-user-appdir=.thunderbird \
			--disable-composer
		
		BUILD_OFFICIAL=0 MOZILLA_OFFICIAL=0 MOZ_THUNDERBIRD=1 $MAKECMD -s export
		BUILD_OFFICIAL=0 MOZILLA_OFFICIAL=0 MOZ_THUNDERBIRD=1 $MAKECMD -s libs
		BUILD_OFFICIAL=0 MOZILLA_OFFICIAL=0 MOZ_THUNDERBIRD=1 DESTDIR=$BUILDDIR/thunderbird-std-pkg make install
		;;
	*)
		echo "Usage: build-mozilla.sh firefox-std|mozilla-std|thunderbird-std"
		;;
esac

	
